yyjson_arr_get

Function yyjson_arr_get 

pub unsafe extern "C" fn yyjson_arr_get(
    arr: *mut yyjson_val,
    idx: usize,
) -> *mut yyjson_val
Returns the element at the specified position in this array. Returns NULL if array is NULL/empty or the index is out of bounds. @warning This function takes a linear search time if array is not flat. For example: [1,{},3] is flat, [1,[2],3] is not flat.