yyjson_equals

Function yyjson_equals 

pub unsafe extern "C" fn yyjson_equals(
    lhs: *mut yyjson_val,
    rhs: *mut yyjson_val,
) -> bool
Returns whether two JSON values are equal (deep compare). Returns false if input is NULL. @note the result may be inaccurate if object has duplicate keys. @warning This function is recursive and may cause a stack overflow if the object level is too deep.