pub unsafe extern "C" fn yyjson_get_real(val: *mut yyjson_val) -> f64Expand description
Returns the content if the value is real number, or 0.0 on error.
Returns 0.0 if val is NULL or type is not real(double).
pub unsafe extern "C" fn yyjson_get_real(val: *mut yyjson_val) -> f64Returns the content if the value is real number, or 0.0 on error.
Returns 0.0 if val is NULL or type is not real(double).