pub unsafe extern "C" fn yyjson_mut_arr_append(
arr: *mut yyjson_mut_val,
val: *mut yyjson_mut_val,
) -> boolExpand description
Inserts a value at the end of the array. @param arr The array to which the value is to be inserted. Returns false if it is NULL or not an array. @param val The value to be inserted. Returns false if it is NULL. @return Whether successful.