pub unsafe extern "C" fn yyjson_mut_arr_insert(
arr: *mut yyjson_mut_val,
val: *mut yyjson_mut_val,
idx: usize,
) -> boolExpand description
Inserts a value into an array at a given index. @param arr The array to which the value is to be inserted. Returns false if it is NULL or not an array. @param val The value to be inserted. Returns false if it is NULL. @param idx The index to which to insert the new value. Returns false if the index is out of range. @return Whether successful. @warning This function takes a linear search time.