yyjson_mut_arr_remove

Function yyjson_mut_arr_remove 

pub unsafe extern "C" fn yyjson_mut_arr_remove(
    arr: *mut yyjson_mut_val,
    idx: usize,
) -> *mut yyjson_mut_val
Removes and returns a value at index. @param arr The array from which the value is to be removed. Returns false if it is NULL or not an array. @param idx The index from which to remove the value. Returns false if the index is out of range. @return Old value, or NULL on error. @warning This function takes a linear search time.