pub unsafe extern "C" fn yyjson_mut_arr_remove_first(
arr: *mut yyjson_mut_val,
) -> *mut yyjson_mut_valExpand description
Removes and returns the first value in this array. @param arr The array from which the value is to be removed. Returns false if it is NULL or not an array. @return The first value, or NULL on error.