yyjson_mut_arr_replace

Function yyjson_mut_arr_replace 

pub unsafe extern "C" fn yyjson_mut_arr_replace(
    arr: *mut yyjson_mut_val,
    idx: usize,
    val: *mut yyjson_mut_val,
) -> *mut yyjson_mut_val
Replaces a value at index and returns old value. @param arr The array to which the value is to be replaced. Returns false if it is NULL or not an array. @param idx The index to which to replace the value. Returns false if the index is out of range. @param val The new value to replace. Returns false if it is NULL. @return Old value, or NULL on error. @warning This function takes a linear search time.