pub unsafe extern "C" fn yyjson_mut_float(
doc: *mut yyjson_mut_doc,
num: f32,
) -> *mut yyjson_mut_valExpand description
Creates and returns a float number value, returns NULL on error.
pub unsafe extern "C" fn yyjson_mut_float(
doc: *mut yyjson_mut_doc,
num: f32,
) -> *mut yyjson_mut_valCreates and returns a float number value, returns NULL on error.