pub unsafe extern "C" fn yyjson_mut_get_num(
val: *mut yyjson_mut_val,
) -> f64Expand description
Returns the content and typecast to double if the value is number.
Returns 0.0 if val is NULL or type is not number(uint/sint/real).
pub unsafe extern "C" fn yyjson_mut_get_num(
val: *mut yyjson_mut_val,
) -> f64Returns the content and typecast to double if the value is number.
Returns 0.0 if val is NULL or type is not number(uint/sint/real).