yyjson_mut_obj_add_double

Function yyjson_mut_obj_add_double 

pub unsafe extern "C" fn yyjson_mut_obj_add_double(
    doc: *mut yyjson_mut_doc,
    obj: *mut yyjson_mut_val,
    key: *const c_char,
    val: f64,
) -> bool
Adds a double value at the end of the object. The key should be a null-terminated UTF-8 string. This function allows duplicated key in one object.

@warning The key string is not copied, you should keep the string unmodified for the lifetime of this JSON document.