yyjson_mut_obj_add_float

Function yyjson_mut_obj_add_float 

pub unsafe extern "C" fn yyjson_mut_obj_add_float(
    doc: *mut yyjson_mut_doc,
    obj: *mut yyjson_mut_val,
    key: *const c_char,
    val: f32,
) -> bool
Adds a float value at the end of the object. The key should be a null-terminated UTF-8 string. This function allows duplicated key in one object.

@warning The key string is not copied, you should keep the string unmodified for the lifetime of this JSON document.