yyjson_mut_obj_add_null

Function yyjson_mut_obj_add_null 

pub unsafe extern "C" fn yyjson_mut_obj_add_null(
    doc: *mut yyjson_mut_doc,
    obj: *mut yyjson_mut_val,
    key: *const c_char,
) -> bool
Adds a null value at the end of the object. The key should be a null-terminated UTF-8 string. This function allows duplicated key in one object.

@warning The key string is not copied, you should keep the string unmodified for the lifetime of this JSON document.