pub unsafe extern "C" fn yyjson_mut_obj_add_obj(
doc: *mut yyjson_mut_doc,
obj: *mut yyjson_mut_val,
key: *const c_char,
) -> *mut yyjson_mut_valExpand description
Creates and adds a new object to the target object.
The key should be a null-terminated UTF-8 string.
This function allows duplicated key in one object.
@warning The key string is not copied, you should keep these strings unmodified for the lifetime of this JSON document. @return The new object, or NULL on error.