pub unsafe extern "C" fn yyjson_mut_obj_add_str(
doc: *mut yyjson_mut_doc,
obj: *mut yyjson_mut_val,
key: *const c_char,
val: *const c_char,
) -> boolExpand description
Adds a string value at the end of the object.
The key and val should be null-terminated UTF-8 strings.
This function allows duplicated key in one object.
@warning The key/value strings are not copied, you should keep these strings unmodified for the lifetime of this JSON document.