pub unsafe extern "C" fn yyjson_mut_obj_getn(
obj: *mut yyjson_mut_val,
key: *const c_char,
key_len: usize,
) -> *mut yyjson_mut_valExpand description
Returns the value to which the specified key is mapped.
Returns NULL if this object contains no mapping for the key.
Returns NULL if obj/key is NULL, or type is not object.
The key should be a UTF-8 string, null-terminator is not required.
The key_len should be the length of the key, in bytes.
@warning This function takes a linear search time.