yyjson_mut_obj_remove_strn

Function yyjson_mut_obj_remove_strn 

pub unsafe extern "C" fn yyjson_mut_obj_remove_strn(
    obj: *mut yyjson_mut_val,
    key: *const c_char,
    len: usize,
) -> *mut yyjson_mut_val
Removes all key-value pairs for the given key. Returns the first value to which the specified key is mapped or NULL if this object contains no mapping for the key. The key should be a UTF-8 string, null-terminator is not required. The len should be the length of the key, in bytes.

@warning This function takes a linear search time.