pub unsafe extern "C" fn yyjson_mut_obj_replace(
obj: *mut yyjson_mut_val,
key: *mut yyjson_mut_val,
val: *mut yyjson_mut_val,
) -> boolExpand description
Replaces value from the object with given key. If the key is not exist, or the value is NULL, it will fail. @param obj The object to which the value is to be replaced. @param key The key, should be a string value. @param val The value to replace into the object. @return Whether successful. @warning This function takes a linear search time.