pub unsafe extern "C" fn yyjson_mut_rawn(
doc: *mut yyjson_mut_doc,
str_: *const c_char,
len: usize,
) -> *mut yyjson_mut_valExpand description
Creates and returns a raw value, returns NULL on error.
The str should be a UTF-8 string, null-terminator is not required.
@warning The input string is not copied, you should keep this string unmodified for the lifetime of this JSON document.