pub unsafe extern "C" fn yyjson_mut_set_bool(
val: *mut yyjson_mut_val,
num: bool,
) -> boolExpand description
Set the value to bool. Returns false if input is NULL. @warning This function should not be used on an existing object or array.
pub unsafe extern "C" fn yyjson_mut_set_bool(
val: *mut yyjson_mut_val,
num: bool,
) -> boolSet the value to bool. Returns false if input is NULL. @warning This function should not be used on an existing object or array.