pub unsafe extern "C" fn yyjson_mut_set_null(
val: *mut yyjson_mut_val,
) -> boolExpand description
Set the value to null. Returns false if input is NULL. @warning This function should not be used on an existing object or array.
pub unsafe extern "C" fn yyjson_mut_set_null(
val: *mut yyjson_mut_val,
) -> boolSet the value to null. Returns false if input is NULL. @warning This function should not be used on an existing object or array.