pub unsafe extern "C" fn yyjson_mut_set_uint(
val: *mut yyjson_mut_val,
num: u64,
) -> boolExpand description
Set the value to uint. Returns false if input is NULL. @warning This function should not be used on an existing object or array.
pub unsafe extern "C" fn yyjson_mut_set_uint(
val: *mut yyjson_mut_val,
num: u64,
) -> boolSet the value to uint. Returns false if input is NULL. @warning This function should not be used on an existing object or array.