yyjson_mut_str

Function yyjson_mut_str 

pub unsafe extern "C" fn yyjson_mut_str(
    doc: *mut yyjson_mut_doc,
    str_: *const c_char,
) -> *mut yyjson_mut_val
Creates and returns a string value, returns NULL on error. The str should be a null-terminated UTF-8 string. @warning The input string is not copied, you should keep this string unmodified for the lifetime of this JSON document.