pub unsafe extern "C" fn yyjson_mut_write_fp(
fp: *mut FILE,
doc: *const yyjson_mut_doc,
flg: yyjson_write_flag,
alc: *const yyjson_alc,
err: *mut yyjson_write_err,
) -> boolExpand description
Write a document to file pointer with options.
@param fp The file pointer.
The data will be written to the current position of the file.
If this fp is NULL or invalid, the function will fail and return false.
@param doc The mutable JSON document.
If this doc is NULL or has no root, the function will fail and return false.
@param flg The JSON write options.
Multiple options can be combined with | operator. 0 means no options.
@param alc The memory allocator used by JSON writer.
Pass NULL to use the libc’s default allocator.
@param err A pointer to receive error information.
Pass NULL if you don’t need error information.
@return true if successful, false if an error occurs.
@warning On 32-bit operating system, files larger than 2GB may fail to write.