pub unsafe extern "C" fn yyjson_obj_iter_init(
obj: *mut yyjson_val,
iter: *mut yyjson_obj_iter,
) -> boolExpand description
Initialize an iterator for this object.
@param obj The object to be iterated over.
If this parameter is NULL or not an object, iter will be set to empty.
@param iter The iterator to be initialized.
If this parameter is NULL, the function will fail and return false.
@return true if the iter has been successfully initialized.
@note The iterator does not need to be destroyed.