pub unsafe extern "C" fn yyjson_set_null(val: *mut yyjson_val) -> boolExpand description
Set the value to null.
Returns false if input is NULL or val is object or array.
@warning This will modify the immutable value, use with caution.
pub unsafe extern "C" fn yyjson_set_null(val: *mut yyjson_val) -> boolSet the value to null.
Returns false if input is NULL or val is object or array.
@warning This will modify the immutable value, use with caution.