pub unsafe extern "C" fn yyjson_mut_arr_remove_range(
arr: *mut yyjson_mut_val,
idx: usize,
len: usize,
) -> boolExpand description
Removes all values within a specified range in the array. @param arr The array from which the value is to be removed. Returns false if it is NULL or not an array. @param idx The start index of the range (0 is the first). @param len The number of items in the range (can be 0). @return Whether successful. @warning This function takes a linear search time.